#ifndef _CAT_H_
#define _CAT_H_

#include <sys/types.h>

#define ITEM(_data_)	((Item *)((_data_)))
#define DISK(_data_)	((Disk *)((_data_)))
#define CATALOG(_data_)	((Catalog *)((_data_)))

#define NO_SPACING 0
#define UI_SPACING 4

enum {
    SB_READY,
    SB_UPDATING,
    SB_SCANNING,
    SB_SAVING,
    SB_EJECTING,
    SB_SEARCHING
};

enum {
    COMPARE_EXACT,
    COMPARE_REGEX,
    COMPARE_GLOB
};

typedef struct _Ui Ui;
typedef struct _Search Search;
typedef struct _Catalog Catalog;
typedef struct _Disk Disk;
typedef struct _Item Item;

/* main GUI */
struct _Ui {
    GtkWidget *window;

    GtkWidget *menu;
    GtkItemFactory *fact;
    
    GtkWidget *dirtree;
    GtkWidget *filelist;

    GtkWidget *status;			/* statusbar */

    GtkWidget *findlist;		/* search results clist */
    Search *search;			/* search info struct */

    GNode *node;			/* skips current dir in the clist */
    Catalog *cat;			/* currently open catalog in the UI */
};

struct _Search {
    Ui *ui;				/* backpointer to Ui */
    Disk *disk;				/* current search disk */
    int sens;				/* case sensitive */
    int type;				/* type (regex, glob, exact) */
    char *pattern;			/* search pattern */
};

/* only one of these for now */
struct _Catalog {
    GList *disks;
    char *catfile;
};

/* each disk in the catalog */
struct _Disk {
    char label[20];			/* disk label */
    unsigned int n_dirs;		/* number of dirs */
    unsigned int n_files;		/* number of files */
    GNode *tree;			/* the data */
    
    unsigned int size_high;		/* top 32 bits of size */
    unsigned int size_low;		/* last 32 bits of size */
};

/* each entry in the disk: file or directory */
struct _Item {
    size_t size;			/* item size */
    time_t time;			/* item ctime */
    unsigned int is_leaf;		/* file or directory? */
    unsigned int level;			/* level inside directory */
    unsigned int namelen;		/* length of name */
    char *name;				/* the name + \0 */
};

#endif /* _CAT_H_ */
